@@ -8,6 +8,7 @@
 #' @param target_dist Target profile distributions to be used. This argument should be `list`
 #' @param target_type Types of target profile distributions. `marginal`, `partial_joint` or `target_data`. See Examples for details
 #' @param partial_joint_name Names of factors representing partial joint distributions. See Examples for details.
+#' @return No return value, called for side effects
 #' @export
 
 weights_pAMCE <- function(formula, factor_name, data, pair, pair_id, cross_int,
@@ -33,7 +34,7 @@ weights_pAMCE <- function(formula, factor_name, data, pair, pair_id, cross_int,
   # Case 1: both are marginal
   if(target_type  == "marginal"){
 
-    if(class(target_dist) != "list"){
+    if(!inherits(target_dist, "list")){
       stop(" if 'target_type = marginal', class(target_dist) should be 'list' ")
     }
 
@@ -47,7 +48,7 @@ weights_pAMCE <- function(formula, factor_name, data, pair, pair_id, cross_int,
   # Case 2: both are data
   if(target_type  == "target_data"){
 
-    if(class(target_dist) != "data.frame"){
+    if(!inherits(target_dist, "data.frame")){
       stop(" if 'target_type = target_data', class(target_dist) should be 'data.frame' ")
     }
 
@@ -70,7 +71,7 @@ weights_pAMCE <- function(formula, factor_name, data, pair, pair_id, cross_int,
       stop(" if 'target_type = partial_joint', please specify 'partial_joint_name' ")
     }
 
-    if(class(target_dist) != "list"){
+    if(!inherits(target_dist, "list")){
       stop(" if 'target_type = partial_joint', class(target_dist) should be 'list' ")
     }
 
